/*
 * Copyright 2010-2012 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.storagegateway.model;
import com.amazonaws.AmazonWebServiceRequest;

/**
 * Container for the parameters to the {@link com.amazonaws.services.storagegateway.AWSStorageGateway#listVolumes(ListVolumesRequest) ListVolumes operation}.
 * <p>
 * This operation lists the iSCSI stored volumes of a gateway. Results are sorted by volume ARN. The response includes only the volume ARNs. If you want
 * additional volume information, use the DescribeStorediSCSIVolumes API.
 * </p>
 * <p>
 * The operation supports pagination. By default, the operation returns a maximum of up to 100 volumes. You can optionally specify the <code>Limit</code>
 * field in the body to limit the number of volumes in the response. If the number of volumes returned in the response is truncated, the response
 * includes a Marker field. You can use this Marker value in your subsequent request to retrieve the next set of volumes.
 * </p>
 *
 * @see com.amazonaws.services.storagegateway.AWSStorageGateway#listVolumes(ListVolumesRequest)
 */
public class ListVolumesRequest extends AmazonWebServiceRequest {

    /**
     * The Amazon Resource Name (ARN) of the gateway. Use the
     * <a>ListGateways</a> operation to return a list of gateways for your
     * account and region.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>50 - 500<br/>
     */
    private String gatewayARN;

    /**
     * A string that indicates the position at which to begin the returned
     * list of volumes. Obtain the marker from the response of a previous
     * List iSCSI Volumes request.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 1000<br/>
     */
    private String marker;

    /**
     * Specifies that the list of volumes returned be limited to the
     * specified number of items. <p>Constraint: Minimum value of 1. Maximum
     * value of 100.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Range: </b>1 - <br/>
     */
    private Integer limit;

    /**
     * The Amazon Resource Name (ARN) of the gateway. Use the
     * <a>ListGateways</a> operation to return a list of gateways for your
     * account and region.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>50 - 500<br/>
     *
     * @return The Amazon Resource Name (ARN) of the gateway. Use the
     *         <a>ListGateways</a> operation to return a list of gateways for your
     *         account and region.
     */
    public String getGatewayARN() {
        return gatewayARN;
    }
    
    /**
     * The Amazon Resource Name (ARN) of the gateway. Use the
     * <a>ListGateways</a> operation to return a list of gateways for your
     * account and region.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>50 - 500<br/>
     *
     * @param gatewayARN The Amazon Resource Name (ARN) of the gateway. Use the
     *         <a>ListGateways</a> operation to return a list of gateways for your
     *         account and region.
     */
    public void setGatewayARN(String gatewayARN) {
        this.gatewayARN = gatewayARN;
    }
    
    /**
     * The Amazon Resource Name (ARN) of the gateway. Use the
     * <a>ListGateways</a> operation to return a list of gateways for your
     * account and region.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>50 - 500<br/>
     *
     * @param gatewayARN The Amazon Resource Name (ARN) of the gateway. Use the
     *         <a>ListGateways</a> operation to return a list of gateways for your
     *         account and region.
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public ListVolumesRequest withGatewayARN(String gatewayARN) {
        this.gatewayARN = gatewayARN;
        return this;
    }
    
    
    /**
     * A string that indicates the position at which to begin the returned
     * list of volumes. Obtain the marker from the response of a previous
     * List iSCSI Volumes request.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 1000<br/>
     *
     * @return A string that indicates the position at which to begin the returned
     *         list of volumes. Obtain the marker from the response of a previous
     *         List iSCSI Volumes request.
     */
    public String getMarker() {
        return marker;
    }
    
    /**
     * A string that indicates the position at which to begin the returned
     * list of volumes. Obtain the marker from the response of a previous
     * List iSCSI Volumes request.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 1000<br/>
     *
     * @param marker A string that indicates the position at which to begin the returned
     *         list of volumes. Obtain the marker from the response of a previous
     *         List iSCSI Volumes request.
     */
    public void setMarker(String marker) {
        this.marker = marker;
    }
    
    /**
     * A string that indicates the position at which to begin the returned
     * list of volumes. Obtain the marker from the response of a previous
     * List iSCSI Volumes request.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 1000<br/>
     *
     * @param marker A string that indicates the position at which to begin the returned
     *         list of volumes. Obtain the marker from the response of a previous
     *         List iSCSI Volumes request.
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public ListVolumesRequest withMarker(String marker) {
        this.marker = marker;
        return this;
    }
    
    
    /**
     * Specifies that the list of volumes returned be limited to the
     * specified number of items. <p>Constraint: Minimum value of 1. Maximum
     * value of 100.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Range: </b>1 - <br/>
     *
     * @return Specifies that the list of volumes returned be limited to the
     *         specified number of items. <p>Constraint: Minimum value of 1. Maximum
     *         value of 100.
     */
    public Integer getLimit() {
        return limit;
    }
    
    /**
     * Specifies that the list of volumes returned be limited to the
     * specified number of items. <p>Constraint: Minimum value of 1. Maximum
     * value of 100.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Range: </b>1 - <br/>
     *
     * @param limit Specifies that the list of volumes returned be limited to the
     *         specified number of items. <p>Constraint: Minimum value of 1. Maximum
     *         value of 100.
     */
    public void setLimit(Integer limit) {
        this.limit = limit;
    }
    
    /**
     * Specifies that the list of volumes returned be limited to the
     * specified number of items. <p>Constraint: Minimum value of 1. Maximum
     * value of 100.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Range: </b>1 - <br/>
     *
     * @param limit Specifies that the list of volumes returned be limited to the
     *         specified number of items. <p>Constraint: Minimum value of 1. Maximum
     *         value of 100.
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public ListVolumesRequest withLimit(Integer limit) {
        this.limit = limit;
        return this;
    }
    
    
    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (gatewayARN != null) sb.append("GatewayARN: " + gatewayARN + ", ");
        if (marker != null) sb.append("Marker: " + marker + ", ");
        if (limit != null) sb.append("Limit: " + limit + ", ");
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getGatewayARN() == null) ? 0 : getGatewayARN().hashCode()); 
        hashCode = prime * hashCode + ((getMarker() == null) ? 0 : getMarker().hashCode()); 
        hashCode = prime * hashCode + ((getLimit() == null) ? 0 : getLimit().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;
    
        if (obj instanceof ListVolumesRequest == false) return false;
        ListVolumesRequest other = (ListVolumesRequest)obj;
        
        if (other.getGatewayARN() == null ^ this.getGatewayARN() == null) return false;
        if (other.getGatewayARN() != null && other.getGatewayARN().equals(this.getGatewayARN()) == false) return false; 
        if (other.getMarker() == null ^ this.getMarker() == null) return false;
        if (other.getMarker() != null && other.getMarker().equals(this.getMarker()) == false) return false; 
        if (other.getLimit() == null ^ this.getLimit() == null) return false;
        if (other.getLimit() != null && other.getLimit().equals(this.getLimit()) == false) return false; 
        return true;
    }
    
}
    